@@ -9,8 +9,6 @@ except (ValueError, ImportError) as e:
 from .util.color import Color
 
 import os
-import sys
-
 
 class Wifite(object):
 
@@ -31,10 +29,9 @@ class Wifite(object):
         from .tools.dependency import Dependency
         Dependency.run_dependency_check()
 
-
     def start(self):
         '''
-        Starts target-scan + attack loop, or launches utilities dpeending on user input.
+        Starts target-scan + attack loop, or launches utilities depending on user input.
         '''
         from .model.result import CrackResult
         from .model.handshake import Handshake
@@ -53,17 +50,15 @@ class Wifite(object):
             Configuration.get_monitor_mode_interface()
             self.scan_and_attack()
 
-
     def print_banner(self):
         '''Displays ASCII art of the highest caliber.'''
         Color.pl(r' {G}  .     {GR}{D}     {W}{G}     .    {W}')
-        Color.pl(r' {G}.´  ·  .{GR}{D}     {W}{G}.  ·  `.  {G}wifite {D}%s{W}' % Configuration.version)
-        Color.pl(r' {G}:  :  : {GR}{D} (¯) {W}{G} :  :  :  {W}{D}automated wireless auditor{W}')
-        Color.pl(r' {G}`.  ·  `{GR}{D} /¯\ {W}{G}´  ·  .´  {C}{D}https://github.com/derv82/wifite2{W}')
-        Color.pl(r' {G}  `     {GR}{D}/¯¯¯\{W}{G}     ´    {W}')
+        Color.pl(r' {G}.´  ·  .{GR}{D}     {W}{G}.  ·  `.  {G}wifite2 {D}%s{W}' % Configuration.version)
+        Color.pl(r' {G}:  :  : {GR}{D} (¯) {W}{G} :  :  :  {W}{D}a wireless auditor by @derv82{W}')
+        Color.pl(r' {G}`.  ·  `{GR}{D} /¯\ {W}{G}´  ·  .´  {W}{D}maintained by kimocoder{W}')
+        Color.pl(r' {G}  `     {GR}{D}/¯¯¯\{W}{G}     ´    {C}{D}https://github.com/kimocoder/wifite2{W}')
         Color.pl('')
 
-
     def scan_and_attack(self):
         '''
         1) Scans for targets, asks user to select targets
@@ -72,21 +67,30 @@ class Wifite(object):
         from .util.scanner import Scanner
         from .attack.all import AttackAll
 
+        attacked_targets = 0
         Color.pl('')
 
         # Scan
         s = Scanner()
+        do_continue = s.find_targets()
         targets = s.select_targets()
 
-        # Attack
-        attacked_targets = AttackAll.attack_multiple(targets)
+        if Configuration.infinite_mode:
+            while do_continue:
+                AttackAll.attack_multiple(targets)
+                do_continue = s.update_targets()
+                if not do_continue:
+                    break
+                targets = s.select_targets()
+            attacked_targets = s.get_num_attacked()
+        else:
+            # Attack
+            attacked_targets = AttackAll.attack_multiple(targets)
 
         Color.pl('{+} Finished attacking {C}%d{W} target(s), exiting' % attacked_targets)
 
-
 ##############################################################
 
-
 def entry_point():
     try:
         wifite = Wifite()
@@ -100,6 +104,5 @@ def entry_point():
 
     Configuration.exit_gracefully(0)
 
-
 if __name__ == '__main__':
     entry_point()
