@@ -23,6 +23,9 @@ class AttackAll(object):
         attacked_targets = 0
         targets_remaining = len(targets)
         for index, target in enumerate(targets, start=1):
+            if Configuration.attack_max != 0 and index > Configuration.attack_max:
+                print("Attacked %d targets, stopping because of the --first flag" % Configuration.attack_max)
+                break
             attacked_targets += 1
             targets_remaining -= 1
 
@@ -44,6 +47,9 @@ class AttackAll(object):
         Attacks a single `target` (wifite.model.target).
         Returns: True if attacks should continue, False otherwise.
         '''
+        if 'MGT' in target.authentication:
+            Color.pl("\n{!}{O}Skipping. Target is using {C}WPA-Enterprise {O}and can not be cracked.")
+            return True
 
         attacks = []
 
@@ -64,6 +70,10 @@ class AttackAll(object):
                     if Configuration.wps_pixie:
                         attacks.append(AttackWPS(target, pixie_dust=True))
 
+                    # Null PIN zero-day attack
+                    if Configuration.wps_pin:
+                        attacks.append(AttackWPS(target, pixie_dust=False, null_pin=True))
+
                     # PIN attack
                     if Configuration.wps_pin:
                         attacks.append(AttackWPS(target, pixie_dust=False))
@@ -81,6 +91,8 @@ class AttackAll(object):
             return True  # Keep attacking other targets (skip)
 
         while len(attacks) > 0:
+            # Needed by infinite attack mode in order to count how many targets were attacked
+            target.attacked = True
             attack = attacks.pop(0)
             try:
                 result = attack.run()
@@ -104,13 +116,14 @@ class AttackAll(object):
 
         return True  # Keep attacking other targets
 
-
     @classmethod
     def user_wants_to_continue(cls, targets_remaining, attacks_remaining=0):
         '''
         Asks user if attacks should continue onto other targets
         Returns:
-            True if user wants to continue, False otherwise.
+            None if the user wants to skip the current target
+            True if the user wants to continue to the next attack on the current target
+            False if the user wants to stop the remaining attacks
         '''
         if attacks_remaining == 0 and targets_remaining == 0:
             return  # No targets or attacksleft, drop out
@@ -128,22 +141,26 @@ class AttackAll(object):
 
         if attacks_remaining > 0:
             prompt += ' {G}continue{W} attacking,'
-            options += '{G}C{W}{D}, {W}'
+            options += '{G}c{W}{D}, {W}'
 
         if targets_remaining > 0:
             prompt += ' {O}skip{W} to the next target,'
             options += '{O}s{W}{D}, {W}'
 
-        options += '{R}e{W})'
-        prompt += ' or {R}exit{W} %s? {C}' % options
+        if Configuration.infinite_mode:
+            options += '{R}r{W})'
+            prompt += ' or {R}return{W} to scanning %s? {C}' % options
+        else:
+            options += '{R}e{W})'
+            prompt += ' or {R}exit{W} %s? {C}' % options
 
         from ..util.input import raw_input
-        answer = raw_input(Color.s(prompt)).lower()
+        Color.p(prompt)
+        answer = raw_input().lower()
 
         if answer.startswith('s'):
             return None  # Skip
-        elif answer.startswith('e'):
-            return False  # Exit
+        elif answer.startswith('e') or answer.startswith('r'):
+            return False # Exit/Return
         else:
             return True  # Continue
-
