@@ -2,13 +2,14 @@
 # -*- coding: utf-8 -*-
 
 import os
+import re
 
 from .util.color import Color
 from .tools.macchanger import Macchanger
 
 class Configuration(object):
     ''' Stores configuration variables and functions for Wifite. '''
-    version = '2.2.5'
+    version = '2.5.2'
 
     initialized = False # Flag indicating config has been initialized
     temp_dir = None     # Temporary directory
@@ -38,16 +39,25 @@ class Configuration(object):
 
         cls.tx_power = 0 # Wifi transmit power (0 is default)
         cls.interface = None
+        cls.min_power = 0  # Minimum power for an access point to be considered a target. Default is 0
+        cls.attack_max = 0
+        cls.skip_crack = False
         cls.target_channel = None # User-defined channel to scan
         cls.target_essid = None # User-defined AP name
         cls.target_bssid = None # User-defined AP BSSID
-        cls.ignore_essid = None # ESSIDs to ignore
+        cls.ignore_essids = None # ESSIDs to ignore
         cls.clients_only = False # Only show targets that have associated clients
+        cls.all_bands = False # Scan for both 2Ghz and 5Ghz channels
+        cls.two_ghz = False # Scan 2.4Ghz channels
         cls.five_ghz = False # Scan 5Ghz channels
+        cls.infinite_mode = False # Attack targets continuously
+        cls.inf_wait_time = 60
         cls.show_bssids = False # Show BSSIDs in targets list
+        cls.show_manufacturers = False # Show manufacturers in targets list
         cls.random_mac = False # Should generate a random Mac address at startup.
         cls.no_deauth = False # Deauth hidden networks & WPA handshake targets
         cls.num_deauths = 1 # Number of deauth packets to send to each target.
+        cls.daemon = False # Don't put back interface back in managed mode
 
         cls.encryption_filter = ['WEP', 'WPA', 'WPS']
 
@@ -78,15 +88,19 @@ class Configuration(object):
         cls.wpa_handshake_dir = 'hs' # Dir to store handshakes
         cls.wpa_strip_handshake = False # Strip non-handshake packets
         cls.ignore_old_handshakes = False # Always fetch a new handshake
+
+        # PMKID variables
         cls.use_pmkid_only = False  # Only use PMKID Capture+Crack attack
         cls.pmkid_timeout = 30  # Time to wait for PMKID capture
+        cls.dont_use_pmkid = False # Don't use PMKID attack
 
         # Default dictionary for cracking
+        cls.cracked_file = 'cracked.txt'
         cls.wordlist = None
         wordlists = [
-            './wordlist-top4800-probable.txt',  # Local file (ran from cloned repo)
-            '/usr/share/dict/wordlist-top4800-probable.txt',  # setup.py with prefix=/usr
-            '/usr/local/share/dict/wordlist-top4800-probable.txt',  # setup.py with prefix=/usr/local
+            './wordlist-probable.txt',  # Local file (ran from cloned repo)
+            '/usr/share/dict/wordlist-probable.txt',  # setup.py with prefix=/usr
+            '/usr/local/share/dict/wordlist-probable.txt',  # setup.py with prefix=/usr/local
             # Other passwords found on Kali
             '/usr/share/wfuzz/wordlist/fuzzdb/wordlists-user-passwd/passwds/phpbb.txt',
             '/usr/share/fuzzdb/wordlists-user-passwd/passwds/phpbb.txt',
@@ -97,14 +111,28 @@ class Configuration(object):
                 cls.wordlist = wlist
                 break
 
+        if os.path.isfile('./usr/share/ieee-data/oui.txt'):
+            manufacturers = './usr/share/ieee-data/oui.txt'
+        else:
+            manufacturers = './ieee-oui.txt'
+
+        if os.path.exists(manufacturers):
+            with open(manufacturers, "r") as f:
+                # Parse txt format into dict
+                lines = f.read().splitlines()
+                k = lambda line: line.split()[0]
+                v = lambda line: ' '.join(line.split()[1:3]).rstrip('.')
+                cls.manufacturers = {k(line):v(line) for line in lines}
+
         # WPS variables
         cls.wps_filter  = False  # Only attack WPS networks
         cls.no_wps      = False  # Do not use WPS attacks (Pixie-Dust & PIN attacks)
         cls.wps_only    = False  # ONLY use WPS attacks on non-WEP networks
         cls.use_bully   = False  # Use bully instead of reaver
+        cls.use_reaver  = False  # Use reaver instead of bully
         cls.wps_pixie   = True
         cls.wps_pin     = True
-        cls.wps_ignore_lock = False  # Skip WPS PIN attack if AP is locked.
+        cls.wps_ignore_lock = False      # Skip WPS PIN attack if AP is locked.
         cls.wps_pixie_timeout = 300      # Seconds to wait for PIN before WPS Pixie attack fails
         cls.wps_fail_threshold = 100     # Max number of failures
         cls.wps_timeout_threshold = 100  # Max number of timeouts
@@ -114,13 +142,15 @@ class Configuration(object):
         cls.check_handshake = None
         cls.crack_handshake = False
 
+        # A list to cache all checked commands (e.g. `which hashcat` will execute only once)
+        cls.existing_commands = {}
+
         # Overwrite config values with arguments (if defined)
         cls.load_from_arguments()
 
         if load_interface:
             cls.get_monitor_mode_interface()
 
-
     @classmethod
     def get_monitor_mode_interface(cls):
         if cls.interface is None:
@@ -140,6 +170,7 @@ class Configuration(object):
         cls.parse_wep_args(args)
         cls.parse_wpa_args(args)
         cls.parse_wps_args(args)
+        cls.parse_pmkid_args(args)
         cls.parse_encryption()
 
         # EvilTwin
@@ -158,23 +189,29 @@ class Configuration(object):
         if args.check_handshake: cls.check_handshake = args.check_handshake
         if args.crack_handshake: cls.crack_handshake = True
 
-
     @classmethod
     def validate(cls):
         if cls.use_pmkid_only and cls.wps_only:
             Color.pl('{!} {R}Bad Configuration:{O} --pmkid and --wps-only are not compatible')
             raise RuntimeError('Unable to attack networks: --pmkid and --wps-only are not compatible together')
-
+        if cls.use_pmkid_only and cls.dont_use_pmkid:
+            Color.pl('{!} {R}Bad Configuration:{O} --pmkid and --no-pmkid are not compatible')
+            raise RuntimeError('Unable to attack networks: --pmkid and --no-pmkid are not compatible together')
 
     @classmethod
     def parse_settings_args(cls, args):
         '''Parses basic settings/configurations from arguments.'''
+
         if args.random_mac:
             cls.random_mac = True
             Color.pl('{+} {C}option:{W} using {G}random mac address{W} ' +
                     'when scanning & attacking')
 
         if args.channel:
+            chn_arg_re = re.compile("^[0-9]+((,[0-9]+)|(-[0-9]+,[0-9]+))*(-[0-9]+)?$")
+            if not chn_arg_re.match(args.channel):
+                raise ValueError("Invalid channel! The format must be 1,3-6,9")
+
             cls.target_channel = args.channel
             Color.pl('{+} {C}option:{W} scanning for targets on channel ' +
                     '{G}%s{W}' % args.channel)
@@ -189,34 +226,73 @@ class Configuration(object):
             Color.pl('{+} {C}option:{W} targeting BSSID ' +
                     '{G}%s{W}' % args.target_bssid)
 
-        if args.five_ghz == True:
+        if args.all_bands:
+            cls.all_bands = True
+            Color.pl('{+} {C}option:{W} including both {G}2.4Ghz and 5Ghz networks{W} in scans')
+
+        if args.two_ghz:
+            cls.two_ghz = True
+            Color.pl('{+} {C}option:{W} including {G}2.4Ghz networks{W} in scans')
+
+        if args.five_ghz:
             cls.five_ghz = True
             Color.pl('{+} {C}option:{W} including {G}5Ghz networks{W} in scans')
 
-        if args.show_bssids == True:
+        if args.infinite_mode:
+            cls.infinite_mode = True
+            Color.p('{+} {C}option:{W} ({G}infinite{W}) attack all neighbors forever')
+            if not args.scan_time:
+                Color.p('; {O}pillage time not selected{W}, '
+                        'using default {G}%d{W}s' % cls.inf_wait_time)
+                args.scan_time = cls.inf_wait_time
+            Color.pl('')
+
+        if args.show_bssids:
             cls.show_bssids = True
             Color.pl('{+} {C}option:{W} showing {G}bssids{W} of targets during scan')
 
-        if args.no_deauth == True:
+        if args.show_manufacturers == True:
+            cls.show_manufacturers = True
+            Color.pl('{+} {C}option:{W} showing {G}manufacturers{W} of targets during scan')
+
+        if args.no_deauth:
             cls.no_deauth = True
             Color.pl('{+} {C}option:{W} will {R}not{W} {O}deauth{W} clients ' +
                     'during scans or captures')
 
+        if args.daemon == True:
+            cls.daemon = True
+            Color.pl('{+} {C}option:{W} will put interface back to managed mode')
+
         if args.num_deauths and args.num_deauths > 0:
             cls.num_deauths = args.num_deauths
             Color.pl('{+} {C}option:{W} send {G}%d{W} deauth packets when deauthing' % (
                 cls.num_deauths))
 
+        if args.min_power and args.min_power > 0:
+            cls.min_power = args.min_power
+            Color.pl('{+} {C}option:{W} Minimum power {G}%d{W} for target to be shown' %
+                     cls.min_power)
+
+        if args.skip_crack:
+            cls.skip_crack = True
+            Color.pl('{+} {C}option:{W} Skip cracking captured handshakes/pmkid {G}enabled{W}')
+
+        if args.attack_max and args.attack_max > 0:
+            cls.attack_max = args.attack_max
+            Color.pl('{+} {C}option:{W} Attack first {G}%d{W} targets from list' %
+                     cls.attack_max)
+
         if args.target_essid:
             cls.target_essid = args.target_essid
             Color.pl('{+} {C}option:{W} targeting ESSID {G}%s{W}' % args.target_essid)
 
-        if args.ignore_essid is not None:
-            cls.ignore_essid = args.ignore_essid
-            Color.pl('{+} {C}option:{W} {O}ignoring ESSIDs that include {R}%s{W}' % (
-                args.ignore_essid))
+        if args.ignore_essids is not None:
+            cls.ignore_essids = args.ignore_essids
+            Color.pl('{+} {C}option: {O}ignoring ESSID(s): {R}%s{W}' %
+                     ', '.join(args.ignore_essids))
 
-        if args.clients_only == True:
+        if args.clients_only:
             cls.clients_only = True
             Color.pl('{+} {C}option:{W} {O}ignoring targets that do not have ' +
                 'associated clients')
@@ -234,7 +310,6 @@ class Configuration(object):
             cls.kill_conflicting_processes = True
             Color.pl('{+} {C}option:{W} kill conflicting processes {G}enabled{W}')
 
-
     @classmethod
     def parse_wep_args(cls, args):
         '''Parses WEP-specific arguments'''
@@ -282,12 +357,15 @@ class Configuration(object):
             cls.wpa_filter = args.wpa_filter
 
         if args.wordlist:
-            if os.path.exists(args.wordlist):
-                cls.wordlist = args.wordlist
-                Color.pl('{+} {C}option:{W} using wordlist {G}%s{W} to crack WPA handshakes' % args.wordlist)
-            else:
+            if not os.path.exists(args.wordlist):
                 cls.wordlist = None
                 Color.pl('{+} {C}option:{O} wordlist {R}%s{O} was not found, wifite will NOT attempt to crack handshakes' % args.wordlist)
+            elif os.path.isfile(args.wordlist):
+                cls.wordlist = args.wordlist
+                Color.pl('{+} {C}option:{W} using wordlist {G}%s{W} to crack WPA handshakes' % args.wordlist)
+            elif os.path.isdir(args.wordlist):
+                cls.wordlist = None
+                Color.pl('{+} {C}option:{O} wordlist {R}%s{O} is a directory, not a file. Wifite will NOT attempt to crack handshakes' % args.wordlist)
 
         if args.wpa_deauth_timeout:
             cls.wpa_deauth_timeout = args.wpa_deauth_timeout
@@ -304,14 +382,6 @@ class Configuration(object):
             Color.pl('{+} {C}option:{W} will {O}ignore{W} existing handshakes ' +
                     '(force capture)')
 
-        if args.use_pmkid_only:
-            cls.use_pmkid_only = True
-            Color.pl('{+} {C}option:{W} will ONLY use {C}PMKID{W} attack on WPA networks')
-
-        if args.pmkid_timeout:
-            cls.pmkid_timeout = args.pmkid_timeout
-            Color.pl('{+} {C}option:{W} will wait {G}%d{W} seconds during {C}PMKID{W} capture')
-
         if args.wpa_handshake_dir:
             cls.wpa_handshake_dir = args.wpa_handshake_dir
             Color.pl('{+} {C}option:{W} will store handshakes to ' +
@@ -356,7 +426,7 @@ class Configuration(object):
                     '(no {O}Pixie-Dust{W}) on targets')
 
         if args.use_bully:
-            from tools.bully import Bully
+            from .tools.bully import Bully
             if not Bully.exists():
                 Color.pl('{!} {R}Bully not found. Defaulting to {O}reaver{W}')
                 cls.use_bully = False
@@ -365,6 +435,16 @@ class Configuration(object):
                 Color.pl('{+} {C}option:{W} use {C}bully{W} instead of {C}reaver{W} ' +
                         'for WPS Attacks')
 
+        if args.use_reaver:
+            from .tools.reaver import Reaver
+            if not Reaver.exists():
+                Color.pl('{!} {R}Reaver not found. Defaulting to {O}bully{W}')
+                cls.use_reaver = False
+            else:
+                cls.use_reaver = args.use_reaver
+                Color.pl('{+} {C}option:{W} use {C}reaver{W} instead of {C}bully{W} ' +
+                        'for WPS Attacks')
+
         if args.wps_pixie_timeout:
             cls.wps_pixie_timeout = args.wps_pixie_timeout
             Color.pl('{+} {C}option:{W} WPS pixie-dust attack will fail after ' +
@@ -384,6 +464,20 @@ class Configuration(object):
             cls.wps_ignore_lock = True
             Color.pl('{+} {C}option:{W} will {O}ignore{W} WPS lock-outs')
 
+    @classmethod
+    def parse_pmkid_args(cls, args):
+        if args.use_pmkid_only:
+            cls.use_pmkid_only = True
+            Color.pl('{+} {C}option:{W} will ONLY use {C}PMKID{W} attack on WPA networks')
+
+        if args.pmkid_timeout:
+            cls.pmkid_timeout = args.pmkid_timeout
+            Color.pl('{+} {C}option:{W} will wait {G}%d seconds{W} during {C}PMKID{W} capture' % args.pmkid_timeout)
+
+        if args.dont_use_pmkid:
+            cls.dont_use_pmkid = True
+            Color.pl('{+} {C}option:{W} will NOT use {C}PMKID{W} attack on WPA networks')
+
     @classmethod
     def parse_encryption(cls):
         '''Adjusts encryption filter (WEP and/or WPA and/or WPS)'''
@@ -406,9 +500,9 @@ class Configuration(object):
     def parse_wep_attacks(cls):
         '''Parses and sets WEP-specific args (-chopchop, -fragment, etc)'''
         cls.wep_attacks = []
-        import sys
+        from sys import argv
         seen = set()
-        for arg in sys.argv:
+        for arg in argv:
             if arg in seen: continue
             seen.add(arg)
             if arg == '-arpreplay':  cls.wep_attacks.append('replay')
@@ -431,7 +525,6 @@ class Configuration(object):
             Color.pl('{+} {C}option:{W} using {G}%s{W} WEP attacks'
                 % '{W}, {G}'.join(cls.wep_attacks))
 
-
     @classmethod
     def temp(cls, subfile=''):
         ''' Creates and/or returns the temporary directory '''
@@ -457,7 +550,6 @@ class Configuration(object):
                 os.remove(cls.temp_dir + f)
             os.rmdir(cls.temp_dir)
 
-
     @classmethod
     def exit_gracefully(cls, code=0):
         ''' Deletes temp and exist with the given code '''
@@ -465,14 +557,16 @@ class Configuration(object):
         Macchanger.reset_if_changed()
         from .tools.airmon import Airmon
         if cls.interface is not None and Airmon.base_interface is not None:
-            Color.pl('{!} {O}Note:{W} Leaving interface in Monitor Mode!')
-            Color.pl('{!} To disable Monitor Mode when finished: ' +
+            if not cls.daemon:
+                Color.pl('{!} {O}Note:{W} Leaving interface in Monitor Mode!')
+                Color.pl('{!} To disable Monitor Mode when finished: ' +
                     '{C}airmon-ng stop %s{W}' % cls.interface)
 
-            # Stop monitor mode
-            #Airmon.stop(cls.interface)
-            # Bring original interface back up
-            #Airmon.put_interface_up(Airmon.base_interface)
+            else:
+                # Stop monitor mode
+                Airmon.stop(cls.interface)
+                # Bring original interface back up
+                Airmon.put_interface_up(Airmon.base_interface)
 
         if Airmon.killed_network_manager:
             Color.pl('{!} You can restart NetworkManager when finished ({C}service network-manager start{W})')
