@@ -15,7 +15,6 @@ class Handshake(object):
         self.bssid = bssid
         self.essid = essid
 
-
     def divine_bssid_and_essid(self):
         '''
             Tries to find BSSID and ESSID from cap file.
@@ -65,7 +64,6 @@ class Handshake(object):
                     self.essid = essid
                     break
 
-
     def has_handshake(self):
         if not self.bssid or not self.essid:
             self.divine_bssid_and_essid()
@@ -79,13 +77,11 @@ class Handshake(object):
 
         return False
 
-
     def tshark_handshakes(self):
         '''Returns list[tuple] of BSSID & ESSID pairs (ESSIDs are always `None`).'''
         tshark_bssids = Tshark.bssids_with_handshakes(self.capfile, bssid=self.bssid)
         return [(bssid, None) for bssid in tshark_bssids]
 
-
     def cowpatty_handshakes(self):
         '''Returns list[tuple] of BSSID & ESSID pairs (BSSIDs are always `None`).'''
         if not Process.exists('cowpatty'):
@@ -106,13 +102,11 @@ class Handshake(object):
                 return [(None, self.essid)]
         return []
 
-
     def pyrit_handshakes(self):
         '''Returns list[tuple] of BSSID & ESSID pairs.'''
         return Pyrit.bssid_essid_with_handshakes(
                 self.capfile, bssid=self.bssid, essid=self.essid)
 
-
     def aircrack_handshakes(self):
         '''Returns tuple (BSSID,None) if aircrack thinks self.capfile contains a handshake / can be cracked'''
         if not self.bssid:
@@ -121,12 +115,11 @@ class Handshake(object):
         command = 'echo "" | aircrack-ng -a 2 -w - -b %s "%s"' % (self.bssid, self.capfile)
         (stdout, stderr) = Process.call(command)
 
-        if 'passphrase not in dictionary' in stdout.lower():
+        if 'passphrase not in dictionary' in stdout.lower() or 'key not found' in stdout.lower():
             return [(self.bssid, None)]
         else:
             return []
 
-
     def analyze(self):
         '''Prints analysis of handshake capfile'''
         self.divine_bssid_and_essid()
@@ -142,7 +135,6 @@ class Handshake(object):
 
         Handshake.print_pairs(self.aircrack_handshakes(), self.capfile, 'aircrack')
 
-
     def strip(self, outfile=None):
         # XXX: This method might break aircrack-ng, use at own risk.
         '''
@@ -172,7 +164,6 @@ class Handshake(object):
             os.remove(outfile)
             pass
 
-
     @staticmethod
     def print_pairs(pairs, capfile, tool=None):
         '''
@@ -195,7 +186,6 @@ class Handshake(object):
             elif essid:
                 Color.pl('%s ({G}%s{W})' % (out_str, essid))
 
-
     @staticmethod
     def check():
         ''' Analyzes .cap file(s) for handshake '''
@@ -220,7 +210,6 @@ class Handshake(object):
             hs.analyze()
             Color.pl('')
 
-
 if __name__ == '__main__':
     print('With BSSID & ESSID specified:')
     hs = Handshake('./tests/files/handshake_has_1234.cap', bssid='18:d6:c7:6d:6b:18', essid='YZWifi')
