@@ -2,9 +2,49 @@
 # -*- coding: utf-8 -*-
 
 from ..util.color import Color
+from ..config import Configuration
 
 import re
 
+class WPSState:
+    NONE, UNLOCKED, LOCKED, UNKNOWN = range(0, 4)
+
+class ArchivedTarget(object):
+    '''
+        Holds information between scans from a previously found target
+    '''
+    def __init__(self, target):
+        self.bssid = target.bssid
+        self.channel = target.channel
+        self.decloaked = target.decloaked
+        self.attacked = target.attacked
+        self.essid = target.essid
+        self.essid_known = target.essid_known
+        self.essid_len = target.essid_len
+
+    def transfer_info(self, other):
+        '''
+            Helper function to transfer relevant fields into another Target or ArchivedTarget
+        '''
+        other.attacked = self.attacked
+
+        # If both targets know the essid, keep decloacked value
+        if self.essid_known and other.essid_known:
+            other.decloaked = self.decloaked
+
+        # The destination target does not know the essid but the source
+        # does, copy that information
+        if self.essid_known and not other.essid_known:
+            other.decloaked = self.decloaked
+            other.essid = self.essid
+            other.essid_known = self.essid_known
+            other.essid_len = self.essid_len
+
+    def __eq__(self, other):
+        # Check if the other class type is either ArchivedTarget or Target
+        return (isinstance(other, self.__class__) or isinstance(other, Target)) \
+               and self.bssid == other.bssid
+
 class Target(object):
     '''
         Holds details for a 'Target' aka Access Point (e.g. router).
@@ -32,10 +72,10 @@ class Target(object):
                     13 ESSID          (HOME-ABCD)
                     14 Key            ()
         '''
-        self.bssid      =     fields[0].strip()
-        self.channel    =     fields[3].strip()
-
-        self.encryption =     fields[5].strip()
+        self.bssid          =     fields[0].strip()
+        self.channel        =     fields[3].strip()
+        self.encryption     =     fields[5].strip()
+        self.authentication =     fields[7].strip()
         if 'WPA' in self.encryption:
             self.encryption = 'WPA'
         elif 'WEP' in self.encryption:
@@ -46,6 +86,7 @@ class Target(object):
         self.power      = int(fields[8].strip())
         if self.power < 0:
             self.power += 100
+        self.max_power = self.power
 
         self.beacons    = int(fields[9].strip())
         self.ivs        = int(fields[10].strip())
@@ -60,8 +101,11 @@ class Target(object):
             self.essid = None # '(%s)' % self.bssid
             self.essid_known = False
 
-        # False=No WPS, None=Locked WPS, True=Unlocked WPS
-        self.wps = False
+        self.wps = WPSState.UNKNOWN
+
+        # Will be set to true once this target will be attacked
+        # Needed to count targets in infinite attack mode
+        self.attacked = False
 
         self.decloaked = False # If ESSID was hidden but we decloaked it.
 
@@ -69,6 +113,30 @@ class Target(object):
 
         self.validate()
 
+    def __eq__(self, other):
+        # Check if the other class type is either ArchivedTarget or Target
+        return (isinstance(other, self.__class__) or isinstance(other, ArchivedTarget)) \
+               and self.bssid == other.bssid
+
+    def transfer_info(self, other):
+        '''
+            Helper function to transfer relevant fields into another Target or ArchivedTarget
+        '''
+        other.wps = self.wps
+        other.attacked = self.attacked
+
+        # If both targets know the essid, keep decloacked value
+        if self.essid_known and other.essid_known:
+            other.decloaked = self.decloaked
+
+        # The destination target does not know the essid but the source
+        # does, copy that information
+        if self.essid_known and not other.essid_known:
+            other.decloaked = self.decloaked
+            other.essid = self.essid
+            other.essid_known = self.essid_known
+            other.essid_len = self.essid_len
+
     def validate(self):
         ''' Checks that the target is valid. '''
         if self.channel == '-1':
@@ -83,7 +151,7 @@ class Target(object):
         if bssid_multicast.match(self.bssid):
             raise Exception('Ignoring target with Multicast BSSID (%s)' % self.bssid)
 
-    def to_str(self, show_bssid=False):
+    def to_str(self, show_bssid=False, show_manufacturer=False):
         '''
             *Colored* string representation of this Target.
             Specifically formatted for the 'scanning' table view.
@@ -104,6 +172,9 @@ class Target(object):
             # Unknown ESSID
             essid = Color.s('{O}%s' % essid)
 
+        if self.power < self.max_power:
+            max_power = self.max_power
+
         # Add a '*' if we decloaked the ESSID
         decloaked_char = '*' if self.decloaked else ' '
         essid += Color.s('{P}%s' % decloaked_char)
@@ -113,16 +184,35 @@ class Target(object):
         else:
             bssid = ''
 
+        if show_manufacturer:
+            oui = ''.join(self.bssid.split(':')[:3])
+            self.manufacturer = Configuration.manufacturers.get(oui,"")
+
+            max_oui_len = 27
+            manufacturer = Color.s('{W}%s  ' % self.manufacturer)
+            # Trim manufacturer name if needed
+            if len(manufacturer) > max_oui_len:
+                manufacturer = manufacturer[0:max_oui_len-3] + '...'
+            else:
+                manufacturer = manufacturer.rjust(max_oui_len)
+        else:
+            manufacturer = ''
+
         channel_color = '{G}'
         if int(self.channel) > 14:
             channel_color = '{C}'
         channel = Color.s('%s%s' % (channel_color, str(self.channel).rjust(3)))
 
-        encryption = self.encryption.rjust(4)
+        encryption = self.encryption.rjust(3)
         if 'WEP' in encryption:
             encryption = Color.s('{G}%s' % encryption)
         elif 'WPA' in encryption:
-            encryption = Color.s('{O}%s' % encryption)
+            if 'PSK' in self.authentication:
+                encryption = Color.s('{O}%s-P' % encryption)
+            elif 'MGT' in self.authentication:
+                encryption = Color.s('{R}%s-E' % encryption)
+            else:
+                encryption = Color.s('{O}%s  ' % encryption)
 
         power = '%sdb' % str(self.power).rjust(3)
         if self.power > 50:
@@ -133,28 +223,29 @@ class Target(object):
             color = 'R'
         power = Color.s('{%s}%s' % (color, power))
 
-        wps = Color.s('{O} n/a')
-        if self.wps == True:
+        if self.wps == WPSState.UNLOCKED:
             wps = Color.s('{G} yes')
-        elif self.wps == False:
+        elif self.wps == WPSState.NONE:
             wps = Color.s('{O}  no')
-        elif self.wps is None:
+        elif self.wps == WPSState.LOCKED:
             wps = Color.s('{R}lock')
+        elif self.wps == WPSState.UNKNOWN:
+            wps = Color.s('{O} n/a')
+        else:
+            wps = ' ERR'
 
         clients = '       '
         if len(self.clients) > 0:
             clients = Color.s('{G}  ' + str(len(self.clients)))
 
-        result = '%s  %s%s  %s  %s  %s  %s' % (
-                essid, bssid, channel, encryption, power, wps, clients)
+        result = '%s  %s%s%s  %s  %s  %s  %s' % (
+                essid, bssid, manufacturer, channel, encryption, power, wps, clients)
         result += Color.s('{W}')
         return result
 
-
 if __name__ == '__main__':
     fields = 'AA:BB:CC:DD:EE:FF,2015-05-27 19:28:44,2015-05-27 19:28:46,1,54,WPA2,CCMP TKIP,PSK,-58,2,0,0.0.0.0,9,HOME-ABCD,'.split(',')
     t = Target(fields)
     t.clients.append('asdf')
     t.clients.append('asdf')
     print(t.to_str())
-
