@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+
 class Dependency(object):
     required_attr_names = ['dependency_name', 'dependency_url', 'dependency_required']
 
@@ -9,30 +10,24 @@ class Dependency(object):
         for attr_name in cls.required_attr_names:
             if not attr_name in cls.__dict__:
                 raise NotImplementedError(
-                    'Attribute "{}" has not been overridden in class "{}"' \
+                    'Attribute "{}" has not been overridden in class "{}"'
                     .format(attr_name, cls.__name__)
                 )
 
-
     @classmethod
     def exists(cls):
         from ..util.process import Process
         return Process.exists(cls.dependency_name)
 
-
     @classmethod
     def run_dependency_check(cls):
         from ..util.color import Color
 
-        from .airmon import Airmon
-        from .airodump import Airodump
         from .aircrack import Aircrack
-        from .aireplay import Aireplay
-        from .ifconfig import Ifconfig
-        from .iwconfig import Iwconfig
+        from .ip import Ip
+        from .iw import Iw
         from .bully import Bully
         from .reaver import Reaver
-        from .wash import Wash
         from .pyrit import Pyrit
         from .tshark import Tshark
         from .macchanger import Macchanger
@@ -40,9 +35,9 @@ class Dependency(object):
 
         apps = [
                 # Aircrack
-                Aircrack, #Airodump, Airmon, Aireplay,
+                Aircrack,  #Airodump, Airmon, Aireplay,
                 # wireless/net tools
-                Iwconfig, Ifconfig,
+                Iw, Ip,
                 # WPS
                 Reaver, Bully,
                 # Cracking/handshakes
@@ -60,7 +55,6 @@ class Dependency(object):
             import sys
             sys.exit(-1)
 
-
     @classmethod
     def fails_dependency_check(cls):
         from ..util.color import Color
