@@ -13,17 +13,15 @@ from ..tools.cowpatty import Cowpatty
 from ..tools.hashcat import Hashcat, HcxPcapTool
 from ..tools.john import John
 
-from datetime import datetime
+from json import loads
 
 import os
 
-
 # TODO: Bring back the 'print' option, for easy copy/pasting. Just one-liners people can paste into terminal.
 
-# TODO: Do not show handshake files that are in cracked.txt with a key (match on filename).
-
 # TODO: --no-crack option while attacking targets (implies user will run --crack later)
 
+
 class CrackHelper:
     '''Manages handshake retrieval, selection, and running the cracking commands.'''
 
@@ -32,6 +30,13 @@ class CrackHelper:
         'PMKID': 'PMKID Hash'
     }
 
+    # Tools for cracking & their dependencies. (RaduNico's code btw!)
+    possible_tools = [
+        ('aircrack', [Aircrack]),
+        ('hashcat', [Hashcat, HcxPcapTool]),
+        ('john', [John, HcxPcapTool]),
+        ('cowpatty', [Cowpatty])
+    ]
 
     @classmethod
     def run(cls):
@@ -41,6 +46,8 @@ class CrackHelper:
         if not Configuration.wordlist:
             Color.p('\n{+} Enter wordlist file to use for cracking: {G}')
             Configuration.wordlist = raw_input()
+            Color.p('{W}')
+
             if not os.path.exists(Configuration.wordlist):
                 Color.pl('{!} {R}Wordlist {O}%s{R} not found. Exiting.' % Configuration.wordlist)
                 return
@@ -53,25 +60,20 @@ class CrackHelper:
             return
 
         hs_to_crack = cls.get_user_selection(handshakes)
-        any_pmkid = any([hs['type'] == 'PMKID' for hs in hs_to_crack])
+        all_pmkid = all([hs['type'] == 'PMKID' for hs in hs_to_crack])
 
-        # Tools for cracking & their dependencies.
-        available_tools = {
-            'aircrack': [Aircrack],
-            'hashcat':  [Hashcat, HcxPcapTool],
-            'john':     [John, HcxPcapTool],
-            'cowpatty': [Cowpatty]
-        }
         # Identify missing tools
         missing_tools = []
-        for tool, dependencies in available_tools.items():
+        available_tools = []
+        for tool, dependencies in cls.possible_tools:
             missing = [
                 dep for dep in dependencies
                 if not Process.exists(dep.dependency_name)
             ]
             if len(missing) > 0:
-                available_tools.pop(tool)
-                missing_tools.append( (tool, missing) )
+                missing_tools.append((tool, missing))
+            else:
+                available_tools.append(tool)
 
         if len(missing_tools) > 0:
             Color.pl('\n{!} {O}Unavailable tools (install to enable):{W}')
@@ -79,26 +81,49 @@ class CrackHelper:
                 dep_list = ', '.join([dep.dependency_name for dep in deps])
                 Color.pl('     {R}* {R}%s {W}({O}%s{W})' % (tool, dep_list))
 
-        Color.p('\n{+} Enter the {C}cracking tool{W} to use ({C}%s{W}): {G}' % (
-            '{W}, {C}'.join(available_tools.keys())))
-        tool_name = raw_input()
-        if tool_name not in available_tools:
-            Color.pl('{!} {R}"%s"{O} tool not found, defaulting to {C}aircrack{W}' % tool_name)
-            tool_name = 'aircrack'
-        elif any_pmkid and tool_name != 'hashcat':
-            Color.pl('{!} {O}Note: PMKID hashes will be cracked using {C}hashcat{W}')
+        if all_pmkid:
+            Color.pl('{!} {O}Note: PMKID hashes can only be cracked using {C}hashcat{W}')
+            tool_name = 'hashcat'
+        else:
+            Color.p('\n{+} Enter the {C}cracking tool{W} to use ({C}%s{W}): {G}' % (
+                '{W}, {C}'.join(available_tools)))
+            tool_name = raw_input()
+            Color.p('{W}')
+
+            if tool_name not in available_tools:
+                Color.pl('{!} {R}"%s"{O} tool not found, defaulting to {C}aircrack{W}' % tool_name)
+                tool_name = 'aircrack'
 
         try:
             for hs in hs_to_crack:
+                if tool_name != 'hashcat' and hs['type'] == 'PMKID':
+                    if 'hashcat' in missing_tools:
+                        Color.pl('{!} {O}Hashcat is missing, therefore we cannot crack PMKID hash{W}')
+                        continue
                 cls.crack(hs, tool_name)
         except KeyboardInterrupt:
             Color.pl('\n{!} {O}Interrupted{W}')
 
+    @classmethod
+    def is_cracked(cls, file):
+        if not os.path.exists(Configuration.cracked_file):
+            return False
+        with open(Configuration.cracked_file) as f:
+            json = loads(f.read())
+        if json is None:
+            return False
+        for result in json:
+            for k in result.keys():
+                v = result[k]
+                if 'file' in k and os.path.basename(v) == file:
+                    return True
+        return False
+
     @classmethod
     def get_handshakes(cls):
         handshakes = []
 
-        skipped_pmkid_files = 0
+        skipped_pmkid_files = skipped_cracked_files = 0
 
         hs_dir = Configuration.wpa_handshake_dir
         if not os.path.exists(hs_dir) or not os.path.isdir(hs_dir):
@@ -110,6 +135,10 @@ class CrackHelper:
             if hs_file.count('_') != 3:
                 continue
 
+            if cls.is_cracked(hs_file):
+                skipped_cracked_files += 1
+                continue
+
             if hs_file.endswith('.cap'):
                 # WPA Handshake
                 hs_type = '4-WAY'
@@ -124,10 +153,20 @@ class CrackHelper:
 
             name, essid, bssid, date = hs_file.split('_')
             date = date.rsplit('.', 1)[0]
-            days,hours = date.split('T')
+            days, hours = date.split('T')
             hours = hours.replace('-', ':')
             date = '%s %s' % (days, hours)
 
+            # Patch for essid with " " (zero) or dot "." in name
+            handshakenew = Handshake(os.path.join(hs_dir, hs_file))
+            handshakenew.divine_bssid_and_essid()
+            essid_discovery = handshakenew.essid
+
+            if essid_discovery is None:
+                essid = essid
+            else:
+                essid = essid_discovery
+
             handshake = {
                 'filename': os.path.join(hs_dir, hs_file),
                 'bssid': bssid.replace('-', ':'),
@@ -148,17 +187,18 @@ class CrackHelper:
             handshakes.append(handshake)
 
         if skipped_pmkid_files > 0:
-            Color.pl('{!} {O}Skipping %d {R}*.16800{O} files because {R}hashcat{O} is missing.' % skipped_pmkid_files)
+            Color.pl('{!} {O}Skipping %d {R}*.16800{O} files because {R}hashcat{O} is missing.{W}\n' % skipped_pmkid_files)
+        if skipped_cracked_files > 0:
+            Color.pl('{!} {O}Skipping %d already cracked files.{W}\n' % skipped_cracked_files)
 
         # Sort by Date (Descending)
         return sorted(handshakes, key=lambda x: x.get('date'), reverse=True)
 
-
     @classmethod
     def print_handshakes(cls, handshakes):
         # Header
         max_essid_len = max([len(hs['essid']) for hs in handshakes] + [len('ESSID (truncated)')])
-        Color.p('{D}  NUM')
+        Color.p('{W}{D}  NUM')
         Color.p('  ' + 'ESSID (truncated)'.ljust(max_essid_len))
         Color.p('  ' + 'BSSID'.ljust(17))
         Color.p('  ' + 'TYPE'.ljust(5))
@@ -170,21 +210,19 @@ class CrackHelper:
         Color.p('  ' + ('-' * 19) + '{W}\n')
         # Handshakes
         for index, handshake in enumerate(handshakes, start=1):
-            bssid = handshake['bssid']
-            date  = handshake['date']
             Color.p('  {G}%s{W}' % str(index).rjust(3))
             Color.p('  {C}%s{W}' % handshake['essid'].ljust(max_essid_len))
             Color.p('  {O}%s{W}' % handshake['bssid'].ljust(17))
             Color.p('  {C}%s{W}' % handshake['type'].ljust(5))
             Color.p('  {W}%s{W}\n' % handshake['date'])
 
-
     @classmethod
     def get_user_selection(cls, handshakes):
         cls.print_handshakes(handshakes)
 
         Color.p('{+} Select handshake(s) to crack ({G}%d{W}-{G}%d{W}, select multiple with {C},{W} or {C}-{W} or {C}all{W}): {G}' % (1, len(handshakes)))
         choices = raw_input()
+        Color.p('{W}')
 
         selection = []
         for choice in choices.split(','):
@@ -201,7 +239,6 @@ class CrackHelper:
 
         return selection
 
-
     @classmethod
     def crack(cls, hs, tool):
         Color.pl('\n{+} Cracking {G}%s {C}%s{W} ({C}%s{W})' % (
@@ -224,7 +261,6 @@ class CrackHelper:
                 hs['essid'], hs['bssid'], crack_result.key))
             crack_result.save()
 
-
     @classmethod
     def crack_4way(cls, hs, tool):
 
@@ -251,9 +287,11 @@ class CrackHelper:
         else:
             return None
 
-
     @classmethod
-    def crack_pmkid(cls, hs, tool_name):
+    def crack_pmkid(cls, hs, tool):
+        if tool != 'hashcat':
+            Color.pl('{!} {O}Note: PMKID hashes can only be cracked using {C}hashcat{W}')
+
         key = Hashcat.crack_pmkid(hs['filename'], verbose=True)
 
         if key is not None:
@@ -264,4 +302,3 @@ class CrackHelper:
 
 if __name__ == '__main__':
     CrackHelper.run()
-
